@@ -1,13 +1,13 @@
 from dataclasses import dataclass, replace
 from typing import Any, TypeVar
 
-from . import chunk, settings, tree
+from . import iterchunk, settings, tree
 
 _SettingT = TypeVar('_SettingT', bound='_DefaultOverride')
 
 
 @dataclass(frozen=True)
-class _DefaultOverride:
+class _DefaultOverride(object):
     def __call__(self: _SettingT, **kwargs: Any) -> _SettingT:
         return replace(self, **kwargs)
 
@@ -16,17 +16,18 @@ class _DefaultOverride:
 class _ChunkPreset(settings._ChunkSetting, _DefaultOverride):
 
     # static pass through
-    assert_tag = staticmethod(chunk.assert_tag)
-    drop_offsets = staticmethod(chunk.drop_offsets)
-    print_chunks = staticmethod(chunk.print_chunks)
+    assert_tag = staticmethod(iterchunk.assert_tag)
+    drop_offsets = staticmethod(iterchunk.drop_offsets)
+    print_chunks = staticmethod(iterchunk.print_chunks)
 
+    # isort: off
     from .resource import (
-        untag,
         read_chunks,
-        mktag,
         write_chunks,
     )
 
+    # isort: on
+
 
 @dataclass(frozen=True)
 class _ShellPreset(settings._IndexSetting, _ChunkPreset):
@@ -37,11 +38,14 @@ class _ShellPreset(settings._IndexSetting, _ChunkPreset):
     findpath = staticmethod(tree.findpath)
     render = staticmethod(tree.render)
 
+    # isort: off
     from .index import (
         map_chunks,
         generate_schema,
     )
 
+    # isort: on
+
 
 preset = _ChunkPreset()
 shell = _ShellPreset()
