@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 import io
 import struct
 from dataclasses import dataclass, replace
@@ -11,7 +9,7 @@ PALETTE_SIZE = 0x300
 
 
 @dataclass(frozen=True)
-class AnimationHeaderV2:
+class AnimationHeaderV2(object):
     framerate: Optional[int] = None
     maxframe: Optional[int] = None
     samplerate: Optional[int] = None
@@ -20,7 +18,7 @@ class AnimationHeaderV2:
 
 
 @dataclass(frozen=True)
-class AnimationHeader:
+class AnimationHeader(object):
     version: int
     nframes: int
     dummy: int
@@ -54,6 +52,5 @@ def from_bytes(data: bytes) -> AnimationHeader:
 
 
 def to_bytes(header: AnimationHeader) -> bytes:
-    return AHDR_V1.pack(header) + (
-        AHDR_V2.pack(header.v2) if header.version == 2 else b''
-    )
+    optional_part = AHDR_V2.pack(header.v2) if header.version == 2 else b''
+    return AHDR_V1.pack(header) + optional_part
