@@ -1,19 +1,17 @@
 #!/usr/bin/env python3
 
-import io
 import struct
-from typing import NamedTuple
 import zlib
 from dataclasses import dataclass
+from typing import NamedTuple
 
 from nutcracker.kernel.structured import StructuredTuple
 
-
 UINT32BE = struct.Struct('>I')
 
 
 @dataclass(frozen=True, order=True)
-class FrameObjectHeader:
+class FrameObjectHeader(object):
     codec: int
     x1: int
     y1: int
@@ -36,9 +34,8 @@ class FrameObject(NamedTuple):
 
 
 def unobj(data: bytes) -> FrameObject:
-    with io.BytesIO(data) as stream:
-        header = FOBJ_META.unpack(stream)
-        return FrameObject(header, stream.read())
+    header = FOBJ_META.unpack_from(data)
+    return FrameObject(header, data[FOBJ_META.size :])
 
 
 def mkobj(meta: FrameObjectHeader, data: bytes) -> bytes:
