@@ -1,31 +1,44 @@
 #!/usr/bin/env python3
 
 import io
-import itertools
-import os
-import pprint
 import operator
+import pprint
 from functools import partial
 from itertools import takewhile
 
 from nutcracker.chiper import xor
-from nutcracker.utils.fileio import read_file
+
 from .preset import sputm
 
+
 def read_directory_leg(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(2), byteorder='little', signed=False)
-        rnums = [int.from_bytes(s.read(1), byteorder='little', signed=False) for i in range(num)]
-        offs = [int.from_bytes(s.read(4), byteorder='little', signed=False) for i in range(num)]
+        rnums = [
+            int.from_bytes(s.read(1), byteorder='little', signed=False)
+            for i in range(num)
+        ]
+        offs = [
+            int.from_bytes(s.read(4), byteorder='little', signed=False)
+            for i in range(num)
+        ]
         return enumerate(zip(rnums, offs))
 
+
 def read_directory_leg_v8(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(4), byteorder='little', signed=False)
-        rnums = [int.from_bytes(s.read(1), byteorder='little', signed=False) for i in range(num)]
-        offs = [int.from_bytes(s.read(4), byteorder='little', signed=False) for i in range(num)]
+        rnums = [
+            int.from_bytes(s.read(1), byteorder='little', signed=False)
+            for i in range(num)
+        ]
+        offs = [
+            int.from_bytes(s.read(4), byteorder='little', signed=False)
+            for i in range(num)
+        ]
         return enumerate(zip(rnums, offs))
 
+
 def read_rnam(data, key=0xFF):
     with io.BytesIO(data) as s:
         while True:
@@ -35,11 +48,13 @@ def read_rnam(data, key=0xFF):
             name = xor.read(s, 9, key=key).split(b'\0')[0].decode()
             yield rnum, name
 
+
 def readcstr(stream, read_fn):
     bound_read = iter(partial(read_fn, stream, 1), b'')
     res = b''.join(takewhile(partial(operator.ne, b'\00'), bound_read))
     return res.decode() if res else None
 
+
 def read_rnam_he(data, key=0xFF):
     with io.BytesIO(data) as s:
         while True:
@@ -56,6 +71,7 @@ def read_anam(data):
         names = [s.read(9).split(b'\0')[0].decode() for i in range(num)]
         return enumerate(names)
 
+
 def read_dobj(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(2), byteorder='little', signed=False)
@@ -63,6 +79,7 @@ def read_dobj(data):
         # [(state, owner)]
         return enumerate((val >> 4, val & 0xFF) for val in values)
 
+
 def read_dobj_v8(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(4), byteorder='little', signed=False)
@@ -74,42 +91,60 @@ def read_dobj_v8(data):
             obj_class = int.from_bytes(s.read(4), byteorder='little', signed=False)
             yield name, (obj_id, state, room, obj_class)
 
+
 def read_dobj_v7(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(2), byteorder='little', signed=False)
         states = list(s.read(num))
         rooms = list(s.read(num))
-        classes = [int.from_bytes(s.read(4), byteorder='little', signed=False) for _ in range(num)]
+        classes = [
+            int.from_bytes(s.read(4), byteorder='little', signed=False)
+            for _ in range(num)
+        ]
         return enumerate(zip(states, rooms, classes))
 
+
 def read_dobj_he(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(2), byteorder='little', signed=False)
         states = list(s.read(num))
         owners = list(s.read(num))
-        rooms =  list(s.read(num))
-        classes = [int.from_bytes(s.read(4), byteorder='little', signed=False) for _ in range(num)]
+        rooms = list(s.read(num))
+        classes = [
+            int.from_bytes(s.read(4), byteorder='little', signed=False)
+            for _ in range(num)
+        ]
         return enumerate(zip(states, owners, rooms, classes))
 
+
 def read_dlfl(data):
     with io.BytesIO(data) as s:
         num = int.from_bytes(s.read(2), byteorder='little', signed=False)
-        offs = [int.from_bytes(s.read(4), byteorder='little', signed=False) for i in range(num)]
+        offs = [
+            int.from_bytes(s.read(4), byteorder='little', signed=False)
+            for i in range(num)
+        ]
         return enumerate(offs)
 
-# def read_directory(data):
-#     with io.BytesIO(data) as s:
-#         num = int.from_bytes(s.read(2), byteorder='little', signed=False)
-#         merged = [(
-#             int.from_bytes(s.read(1), byteorder='little', signed=False),
-#             int.from_bytes(s.read(4), byteorder='little', signed=False)
-#         ) for i in range(num)]
-#         print(enumerate(merged))
+
+def read_directory(data):
+    with io.BytesIO(data) as s:
+        num = int.from_bytes(s.read(1), byteorder='little', signed=False)
+        merged = [
+            (
+                int.from_bytes(s.read(1), byteorder='little', signed=False),
+                int.from_bytes(s.read(4), byteorder='little', signed=False),
+            )
+            for i in range(num)
+        ]
+        return merged
+
 
 def read_inner_uint16le_v7(pid, data, off):
     res = int.from_bytes(data[12:14], byteorder='little', signed=False)
     return res
 
+
 def read_inner_uint16le(pid, data, off):
     res = int.from_bytes(data[8:10], byteorder='little', signed=False)
     # TODO: fix offset for FT + DIG as in the following commented line
@@ -135,13 +170,17 @@ def read_uint32le(pid, data, off):
 def compare_pid_off(directory, base: int = 0):
     def inner(pid, data, off):
         return next((k for k, v in directory.items() if v == (pid, off + base)), None)
+
     return inner
 
+
 def compare_off_he(directory):
     def inner(pid, data, off):
         return next((k for k, v in directory.items() if v == off + 16), None)
+
     return inner
 
+
 def read_index_v5tov7(root):
     for t in root:
         sputm.render(t)
@@ -185,6 +224,7 @@ def read_index_v5tov7(root):
         'AKOS': compare_pid_off(dcos),
     }
 
+
 def read_index_v7(root):
     for t in root:
         sputm.render(t)
@@ -228,6 +268,7 @@ def read_index_v7(root):
         'AKOS': compare_pid_off(dcos),
     }
 
+
 def read_index_v8(root):
     for t in root:
         sputm.render(t)
@@ -273,12 +314,15 @@ def read_index_v8(root):
         'AKOS': compare_pid_off(dcos, 8),
     }
 
+
 def get_object_id_from_name_v8(dobj):
     def compare_name(pid, data, off):
         name = data[8:48].split(b'\0')[0].decode()
         return dobj[name][0]
+
     return compare_name
 
+
 def read_index_he(root):
     dtlk = None  # prevent `referenced before assignment` error
     for t in root:
@@ -327,7 +371,7 @@ def read_index_he(root):
         'OBIM': read_inner_uint16le,
         'OBCD': read_inner_uint16le,
         'LSCR': read_uint8le,
-        'LSC2': read_uint8le,
+        'LSC2': read_uint32le,
         'SCRP': compare_pid_off(dscr),
         'CHAR': compare_pid_off(dchr),
         'DIGI': compare_pid_off(dsou),
@@ -336,101 +380,6 @@ def read_index_he(root):
         'MULT': compare_pid_off(dmul),
         'AWIZ': compare_pid_off(dmul),
         'RMDA': compare_pid_off(drmd),
-        'TALK': compare_pid_off(dtlk),
+        'TALK': compare_pid_off(dsou),
+        'TLKE': compare_pid_off(dtlk),
     }
-
-def save_tree(cfg, element, basedir='.'):
-    if not element:
-        return
-    path = os.path.join(basedir, element.attribs['path'])
-    if element.children:
-        os.makedirs(path, exist_ok=True)
-        for c in element.children:
-            save_tree(cfg, c, basedir=basedir)
-    else:
-        with open(path, 'wb') as f:
-            f.write(cfg.mktag(element.tag, element.data))
-
-
-if __name__ == '__main__':
-    import argparse
-    from typing import Dict
-
-    from .types import Chunk
-
-    parser = argparse.ArgumentParser(description='read smush file')
-    parser.add_argument('filename', help='filename to read from')
-    args = parser.parse_args()
-
-    basedir = os.path.basename(args.filename)
-
-    # Configuration for HE games
-    index_suffix = '.HE0'
-    resource_suffix = '.HE1'
-    # resource_suffix = '.(a)'
-    read_index = read_index_he
-    chiper_key = 0x69
-    max_depth = 4
-
-    # # Configuration for SCUMM v5-v6 games
-    # index_suffix = '.000'
-    # resource_suffix = '.001'
-    # read_index = read_index_v5tov7
-    # chiper_key = 0x69
-    # max_depth = 4
-
-    # # Configuration for SCUMM v7 games
-    # index_suffix = '.LA0'
-    # resource_suffix = '.LA1'
-    # read_index = read_index_v5tov7
-    # chiper_key = 0x00
-    # max_depth = 3
-
-    index = read_file(args.filename + index_suffix, key=chiper_key)
-
-    s = sputm.generate_schema(index)
-    pprint.pprint(s)
-
-    root = sputm(schema=s).map_chunks(index)
-
-    # root = list(root)
-    # os.makedirs(basedir, exist_ok=True)
-    # with open(os.path.join(basedir, 'index.xml'), 'w') as f:
-    #     for t in root:
-    #         sputm.render(t, stream=f)
-    #         print(t, t.data)
-
-    idgens = read_index(root)
-
-    resource = read_file(args.filename + resource_suffix, key=chiper_key)
-
-    # # commented out, use pre-calculated index instead, as calculating is time-consuming
-    # s = sputm.generate_schema(resource)
-    # pprint.pprint(s)
-    # root = sputm.map_chunks(resource, idgen=idgens, schema=s)
-
-    paths: Dict[str, Chunk] = {}
-
-    def update_element_path(parent, chunk, offset):
-        get_gid = idgens.get(chunk.tag)
-        gid = get_gid and get_gid(parent and parent.attribs['gid'], chunk.data, offset)
-
-        base = chunk.tag + (f'_{gid:04d}' if gid is not None else '' if not get_gid else f'_o_{offset:04X}')
-
-        dirname = parent.attribs['path'] if parent else ''
-        path = os.path.join(dirname, base)
-
-        if path in paths:
-            path += 'd'
-        assert path not in paths, path
-        paths[path] = chunk
-
-        res = {'path': path, 'gid': gid}
-        return res
-
-    root = sputm(max_depth=max_depth).map_chunks(resource, extra=update_element_path)
-    os.makedirs(basedir, exist_ok=True)
-    with open(os.path.join(basedir, 'rpdump.xml'), 'w') as f:
-        for t in root:
-            sputm.render(t, stream=f)
-            save_tree(sputm, t, basedir=basedir)
