@@ -1,14 +1,14 @@
 from functools import partial
-from typing import Callable, Dict, IO, Iterable, Mapping, Optional, TypeVar
+from typing import IO, Callable, Dict, Iterable, Mapping, Optional, TypeVar
 
 from .parser import (
     ByteValue,
     CString,
     DWordValue,
     RefOffset,
-    WordValue,
-    Statement,
     ScriptArg,
+    Statement,
+    WordValue,
 )
 
 OpTable = Mapping[int, Callable[[int, IO[bytes]], Statement]]
@@ -146,7 +146,7 @@ def wait_ops_v8(stream: IO[bytes]) -> Iterable[ScriptArg]:
     return (cmd,)
 
 
-def write_file(stream: IO[bytes]) -> Iterable[ScriptArg]:
+def file_op(stream: IO[bytes]) -> Iterable[ScriptArg]:
     cmd = ByteValue(stream)
     if ord(cmd.op) in {8}:
         return (cmd, ByteValue(stream))
@@ -170,7 +170,7 @@ def makeop(
 OPCODES_v6: OpTable = realize({
     0x00: makeop('o6_pushByte', extended_b_op),
     0x01: makeop('o6_pushWord', extended_w_op),
-    # TODO: 0x02: makeop('o6_pushByteVar'),
+    0x02: makeop('o6_pushByteVar', extended_b_op),
     0x03: makeop('o6_pushWordVar', extended_w_op),
     # TODO: 0x06: makeop('o6_byteArrayRead'),
     0x07: makeop('o6_wordArrayRead', extended_w_op),
@@ -276,13 +276,13 @@ OPCODES_v6: OpTable = realize({
     0xA2: makeop('o6_getActorElevation'),
     0xA3: makeop('o6_getVerbEntrypoint'),
     0xA4: makeop('o6_arrayOps', array_ops_v6),
-    # TODO: 0xa5: makeop('o6_saveRestoreVerbs'),
+    0xA5: makeop('o6_saveRestoreVerbs', extended_b_op),
     0xA6: makeop('o6_drawBox'),
     0xA7: makeop('o6_pop'),
     0xA8: makeop('o6_getActorWidth'),
     0xA9: makeop('o6_wait', wait_ops),
     0xAA: makeop('o6_getActorScaleX'),
-    # TODO: 0xab: makeop('o6_getActorAnimCounter'),
+    0xAB: makeop('o6_getActorAnimCounter'),
     0xAC: makeop('o6_soundKludge'),
     0xAD: makeop('o6_isAnyOf'),
     0xAE: makeop('o6_systemOps', extended_b_op),
@@ -307,7 +307,7 @@ OPCODES_v6: OpTable = realize({
     0xC4: makeop('o6_abs'),
     0xC5: makeop('o6_distObjectObject'),
     # TODO: 0xc6: makeop('o6_distObjectPt'),
-    0xc7: makeop('o6_distPtPt'),
+    0xC7: makeop('o6_distPtPt'),
     0xC8: makeop('o6_kernelGetFunctions'),
     0xC9: makeop('o6_kernelSetFunctions'),
     0xCA: makeop('o6_delayFrames'),
@@ -352,7 +352,7 @@ OPCODES_he60 = realize({
     0xE2: makeop('o60_localizeArrayToScript'),
     0xE9: makeop('o60_seekFilePos'),
     # TODO: 0xea: makeop('o60_redimArray'),
-    # TODO: 0xeb: makeop('o60_readFilePos'),
+    0xEB: makeop('o60_readFilePos'),
     0xEC: None,
     0xED: None,
 })
@@ -379,7 +379,7 @@ OPCODES_he71: OpTable = realize({
     0xED: makeop('o71_getStringWidth'),
     0xEF: makeop('o71_appendString'),
     # TODO: 0xf0: makeop('o71_concatString'),
-    # TODO: 0xf1: makeop('o71_compareString'),
+    0xF1: makeop('o71_compareString'),
     0xF5: makeop('o71_getStringLenForWidth'),
     0xF6: makeop('o71_getCharIndexInString'),
     # TODO: 0xf7: makeop('o71_findBox'),
@@ -398,7 +398,7 @@ OPCODES_he72: OpTable = realize({
     0x4A: None,
     0x4E: None,
     0x50: makeop('o72_resetCutscene'),
-    # TODO: 0x52: makeop('o72_findObjectWithClassOf'),
+    0x52: makeop('o72_findObjectWithClassOf'),
     0x54: makeop('o72_getObjectImageX'),
     0x55: makeop('o72_getObjectImageY'),
     0x56: makeop('o72_captureWizImage'),
@@ -410,7 +410,7 @@ OPCODES_he72: OpTable = realize({
     0x61: makeop('o72_drawObject', extended_b_op),
     0x62: makeop('o72_printWizImage'),
     0x63: makeop('o72_getArrayDimSize', extended_bw_op),
-    # TODO: 0x64: makeop('o72_getNumFreeArrays'),
+    0x64: makeop('o72_getNumFreeArrays'),
     0x97: None,
     0x9C: makeop('o72_roomOps', extended_b_op),
     0x9D: makeop('o72_actorOps', extended_b_op),
@@ -422,14 +422,14 @@ OPCODES_he72: OpTable = realize({
     0xBB: makeop('o72_talkEgo', msg_op),
     0xBC: makeop('o72_dimArray', extended_bw_op),
     0xC0: makeop('o72_dim2dimArray', extended_bw_op),
-    # TODO: 0xc1: makeop('o72_traceStatus'),
+    0xC1: makeop('o72_traceStatus'),
     0xC8: makeop('o72_kernelGetFunctions'),
     0xCE: makeop('o72_drawWizImage'),
     0xCF: makeop('o72_debugInput'),
     0xD5: makeop('o72_jumpToScript', extended_b_op),
     0xDA: makeop('o72_openFile'),
-    0xDB: makeop('o72_readFile', extended_b_op),
-    0xDC: makeop('o72_writeFile', write_file),
+    0xDB: makeop('o72_readFile', file_op),
+    0xDC: makeop('o72_writeFile', file_op),
     0xDD: makeop('o72_findAllObjects'),
     0xDE: makeop('o72_deleteFile'),
     0xDF: makeop('o72_rename'),
@@ -446,7 +446,7 @@ OPCODES_he72: OpTable = realize({
 OPCODES_he80: OpTable = realize({
     **OPCODES_he72,
     0x45: makeop('o80_createSound', extended_b_op),
-    # TODO: 0x46: makeop('o80_getFileSize'),
+    0x46: makeop('o80_getFileSize'),
     0x48: makeop('o80_stringToInt'),
     0x49: makeop('o80_getSoundVar'),
     0x4A: makeop('o80_localizeArrayToRoom'),
@@ -461,10 +461,54 @@ OPCODES_he80: OpTable = realize({
     0x9E: None,
     0xA5: None,
     0xAC: makeop('o80_drawWizPolygon'),
-    # TODO: 0xe0: makeop('o80_drawLine'),
+    0xE0: makeop('o80_drawLine', extended_b_op),
     0xE3: makeop('o80_pickVarRandom', extended_w_op),
 })
 
+OPCODES_he90: OpTable = realize({
+    **OPCODES_he80,
+    0x0A: makeop('o90_dup_n', extended_w_op),
+    0x1C: makeop('o90_wizImageOps', extended_b_op),
+    0x1D: makeop('o90_min'),
+    0x1E: makeop('o90_max'),
+    0x1F: makeop('o90_sin'),
+    0x20: makeop('o90_cos'),
+    # TODO: 0x21: makeop('o90_sqrt'),
+    # TODO: 0x22: makeop('o90_atan2'),
+    0x23: makeop('o90_getSegmentAngle'),
+    0x24: makeop('o90_getDistanceBetweenPoints', extended_b_op),
+    0x25: makeop('o90_getSpriteInfo', extended_b_op),
+    0x26: makeop('o90_setSpriteInfo', extended_b_op),
+    0x27: makeop('o90_getSpriteGroupInfo', extended_b_op),
+    0x28: makeop('o90_setSpriteGroupInfo', extended_b_op),
+    0x29: makeop('o90_getWizData', extended_b_op),
+    # TODO: 0x2a: makeop('o90_getActorData'),
+    0x2B: makeop('o90_startScriptUnk', extended_b_op),
+    # TODO: 0x2c: makeop('o90_jumpToScriptUnk'),
+    # TODO: 0x2d: makeop('o90_videoOps'),
+    # TODO: 0x2e: makeop('o90_getVideoData'),
+    0x2F: makeop('o90_floodFill', extended_b_op),
+    0x30: makeop('o90_mod'),
+    0x31: makeop('o90_shl'),
+    0x32: makeop('o90_shr'),
+    # TODO: 0x33: makeop('o90_xor'),
+    0x34: makeop('o90_findAllObjectsWithClassOf'),
+    0x35: makeop('o90_getPolygonOverlap'),
+    0x36: makeop('o90_cond'),
+    0x37: makeop('o90_dim2dim2Array', extended_bw_op),
+    0x38: makeop('o90_redim2dimArray', extended_bw_op),
+    # TODO: 0x39: makeop('o90_getLinesIntersectionPoint'),
+    0x3A: makeop('o90_sortArray', extended_bw_op),
+    0x44: makeop('o90_getObjectData', extended_b_op),
+    0x69: makeop('disabled_windowOps', extended_b_op),
+    0x94: makeop('o90_getPaletteData', extended_b_op),
+    0x9e: makeop('o90_paletteOps', extended_b_op),
+    # TODO: 0xa5: makeop('o90_fontUnk'),
+    # TODO: 0xab: makeop('o90_getActorAnimProgress'),
+    # TODO: 0xc8: makeop('o90_kernelGetFunctions'),
+    # TODO: 0xc9: makeop('o90_kernelSetFunctions'),,
+})
+
 OPCODES_v8: OpTable = realize({
     0x01: makeop('o6_pushWord', extended_dw_op),
     0x02: makeop('o6_pushWordVar', extended_dw_op),
